==> mythx-models-0.1.0.tar.gz: mythx-models-0.1.0/mythx_models/request/version.py <==
"""This module contains the VersionRequest domain model."""

from mythx_models.request.base import BaseRequest


class VersionRequest(BaseRequest):
    """Perform an API request that fetches API version information."""

    @property
    def endpoint(self):
        """The API's version endpoint.

        :return: A string denoting the version endpoint without the host prefix
        """
        return "v1/version"

    @property
    def method(self):
        """The HTTP method to perform.

        :return: The uppercase HTTP method, e.g. "POST"
        """
        return "GET"

    @property
    def payload(self):
        """The request's payload data.

        :return: A Python dict to be serialized into JSON format and submitted to the endpoint.
        """
        return {}

    @property
    def parameters(self):
        """Additional URL parameters

        :return: A dict (str -> str) instance mapping parameter name to parameter content
        """
        return {}

    @property
    def headers(self):
        """Additional request headers.

        :return: A dict (str -> str) instance mapping header name to header content
        """
        return {}

    @classmethod
    def from_dict(cls, d):
        """Create the request domain model from a dict.

        This also validates the dict's schema and raises a :code:`RequestValidationError`
        if any required keys are missing or the data is malformed.

        :param d: The dict to deserialize from
        :return: The domain model with the data from :code:`d` filled in
        """
        return cls()

    def to_dict(self):
        """Serialize the request model to a Python dict.

        :return: A dict holding the request model data
        """
        return {}

==> mythx-models-1.7.3.tar.gz: mythx-models-1.7.3/mythx_models/request/version.py <==
"""This module contains the VersionRequest domain model."""

from typing import Dict

from mythx_models.request.base import BaseRequest


class VersionRequest(BaseRequest):
    """Perform an API request that fetches API version information."""

    @property
    def endpoint(self) -> str:
        """The API's version endpoint.

        :return: A string denoting the version endpoint without the host prefix
        """
        return "v1/version"

    @property
    def method(self) -> str:
        """The HTTP method to perform.

        :return: The uppercase HTTP method, e.g. "POST"
        """
        return "GET"

    @property
    def payload(self) -> Dict:
        """The request's payload data.

        :return: A Python dict to be serialized into JSON format and submitted to the endpoint.
        """
        return {}

    @property
    def parameters(self) -> Dict:
        """Additional URL parameters.

        :return: A dict (str -> str) instance mapping parameter name to parameter content
        """
        return {}

    @property
    def headers(self) -> Dict:
        """Additional request headers.

        :return: A dict (str -> str) instance mapping header name to header content
        """
        return {}

    @classmethod
    def from_dict(cls, d) -> "VersionRequest":
        """Create the request domain model from a dict.

        This also validates the dict's schema and raises a :code:`ValidationError`
        if any required keys are missing or the data is malformed.

        :param d: The dict to deserialize from
        :return: The domain model with the data from :code:`d` filled in
        """
        return cls()

    def to_dict(self) -> Dict:
        """Serialize the request model to a Python dict.

        :return: A dict holding the request model data
        """
        return {}
